@@ -23,7 +23,6 @@ from BTrees.OOBTree import OOBTree
 from persistent import Persistent
 
 from zope.annotation.interfaces import IAnnotations
-from zope.viewlet.viewlet import CSSViewlet
 from zope.security.proxy import removeSecurityProxy
 from zope.intid.interfaces import IIntIds
 from zope.container.btree import BTreeContainer
@@ -338,9 +337,6 @@ class JournalAppStartup(StartUpBase):
             self.app['schooltool.lyceum.journal'] = LyceumJournalContainer()
 
 
-JournalCSSViewlet = CSSViewlet("journal.css")
-
-
 class JournalEditorsCrowd(ConfigurableCrowd):
 
     setting_key = 'administration_can_grade_journal'
